@@ -7,7 +7,7 @@
 #  define VTKRENDERINGLOD_NO_EXPORT
 #else
 #  ifndef VTKRENDERINGLOD_EXPORT
-#    ifdef vtkRenderingLOD_EXPORTS
+#    ifdef RenderingLOD_EXPORTS
         /* We are building this library */
 #      define VTKRENDERINGLOD_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,17 +23,20 @@
 
 #ifndef VTKRENDERINGLOD_DEPRECATED
 #  define VTKRENDERINGLOD_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKRENDERINGLOD_DEPRECATED_EXPORT VTKRENDERINGLOD_EXPORT __attribute__ ((__deprecated__))
-#  define VTKRENDERINGLOD_DEPRECATED_NO_EXPORT VTKRENDERINGLOD_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKRENDERINGLOD_NO_DEPRECATED
+#ifndef VTKRENDERINGLOD_DEPRECATED_EXPORT
+#  define VTKRENDERINGLOD_DEPRECATED_EXPORT VTKRENDERINGLOD_EXPORT VTKRENDERINGLOD_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkFiltersModelingModule.h"
-#include "vtkRenderingCoreModule.h"
-
+#ifndef VTKRENDERINGLOD_DEPRECATED_NO_EXPORT
+#  define VTKRENDERINGLOD_DEPRECATED_NO_EXPORT VTKRENDERINGLOD_NO_EXPORT VTKRENDERINGLOD_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKRENDERINGLOD_NO_DEPRECATED
+#    define VTKRENDERINGLOD_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKRENDERINGLOD_EXPORT_H */
