@@ -16,10 +16,21 @@
 #define vtk_libproj_h
 
 /* Use the libproj library configured for VTK.  */
-/* #undef VTK_USE_SYSTEM_LIBPROJ */
-#ifdef VTK_USE_SYSTEM_LIBPROJ
-# include <projects.h>
-# include <proj_api.h>
+#define VTK_MODULE_USE_EXTERNAL_vtklibproj 1
+
+#define VTK_LibPROJ_MAJOR_VERSION 8
+
+#if VTK_LibPROJ_MAJOR_VERSION < 5
+# define PROJ_VERSION_MAJOR 8
+# define proj_list_operations pj_get_list_ref
+#endif
+
+#if VTK_MODULE_USE_EXTERNAL_vtklibproj
+# if VTK_LibPROJ_MAJOR_VERSION >= 5
+#  include <proj.h>
+# else
+#  include <projects.h>
+# endif
 # include <geodesic.h>
 #else
 # include <vtklibproj/src/projects.h>
